@@ -123,3 +123,17 @@ def touch(filename):
         with open(filename, "wb") as fobj:
             pass
     return os.stat(filename)
+
+def expand(filename):
+    """Expand user and expand vars.
+    """
+    return os.path.abspath(os.path.expandvars(os.path.expanduser(filename)))
+
+def first_exists_file(*filenames):
+    """Return the first exists file's abspath. If none file exists, return None.
+    """
+    for filename in filenames:
+        filename = expand(filename)
+        if os.path.exists(filename):
+            return filename
+    return None
