@@ -95,3 +95,11 @@ def compare(old_set, new_set):
     set_update = old_set.intersection(new_set)
 
     return set_new, set_delete, set_update
+
+def first(*thelist, check=lambda x: x, default=None):
+    """Return first non-none value. check is a callable function that returns the real value.
+    """
+    for value in thelist:
+        if check(value) != None:
+            return value
+    return default
