@@ -9,6 +9,7 @@ import bizerror
 import typing
 import math
 import re
+import uuid
 from decimal import Decimal
 
 
@@ -428,11 +429,11 @@ def clean(value, clean_chars):
             value2 += c
     return value2
 
-def camel(value, **kwargs):
-    """named-paramters: clean:bool=False, clean_chars:string=string.ascii_letters + string.digits
-    """
-    do_clean = kwargs.get("clean", False)
-    clean_chars = kwargs.get("clean_chars", string.ascii_letters + string.digits)
+do_clean = clean
+
+def camel(value, clean=False, clean_chars=string.ascii_letters + string.digits, lower_first=False):
+    if value is None:
+        return None
     words = []
     word_chars = set(string.ascii_letters)
     word = ""
@@ -452,13 +453,16 @@ def camel(value, **kwargs):
         words.append(word.capitalize())
     if non_word:
         words.append(non_word)
-    if do_clean:
+    if clean:
         clean_chars = set(clean_chars)
-        return "".join([clean(x, clean_chars) for x in words])
+        result = "".join([do_clean(x, clean_chars) for x in words])
     else:
-        return "".join(words)
-
-
+        result = "".join(words)
+    if len(result) < 1:
+        return result
+    if lower_first:
+        result = result[0].lower() + result[1:]
+    return result
 
 def no_mapping(value):
     return value
@@ -531,3 +535,32 @@ def unquote(value, quotes=None):
         if value.startswith(quote_pair[0]) and value.endswith(quote_pair[1]):
             return value[len(quote_pair[0]):-1*len(quote_pair[1])]
     return value
+
+
+def is_uuid(value):
+    if isinstance(value, uuid.UUID):
+        return True
+    if isinstance(value, bytes):
+        try:
+            value2 = uuid.UUID(bytes=value)
+            return True
+        except ValueError:
+            return False
+    elif isinstance(value, (tuple, list)):
+        try:
+            value2 = uuid.UUID(fields=value)
+            return True
+        except ValueError:
+            return False
+    elif isinstance(value, int):
+        try:
+            value2 = uuid.UUID(int=value)
+            return True
+        except ValueError:
+            return False
+    else:
+        try:
+            value2 = uuid.UUID(value)
+            return True
+        except ValueError:
+            return False
